@@ -214,6 +214,10 @@ typedef struct {
 #include "precpos.h"
 #include "garmin_export.h"
 
+#ifdef ENABLE_OSM_GPS_MAP
+#include "map-tool.h"
+#endif
+
 #ifdef USE_MAEMO
 #include "dbus.h"
 #endif
