@@ -587,7 +587,7 @@ void cachelist_dialog(appdata_t *appdata, gpx_t *gpx) {
   g_object_set_data(G_OBJECT(window), "cur_view", appdata->cur_view);
 
   appdata->cur_gpx = gpx;
-  char *title = g_strdup_printf("GPXView - %s", gpx->name);
+  char *title = g_strdup_printf("%s - GPXView", gpx->name);
   gtk_window_set_title(GTK_WINDOW(window), title);
   g_free(title);
 
@@ -1509,6 +1509,13 @@ cb_menu_export_garmin(GtkWidget *widget, gpointer data) {
   garmin_export(appdata);
 }
 
+#ifdef ENABLE_OSM_GPS_MAP
+static void 
+cb_menu_map(GtkWidget *window, gpointer data) {
+  map((appdata_t *)data);
+}
+#endif
+
 static void 
 cb_menu_geomath(GtkWidget *window, gpointer data) {
   geomath_dialog((appdata_t *)data);
@@ -1572,12 +1579,16 @@ static GtkWidget *app_submenu_create(appdata_t *appdata,
 	    HILDON_BUTTON_ARRANGEMENT_VERTICAL,
 	    _(menu_entries->label), _(menu_entries->desc));
 
-      g_signal_connect(button, "clicked", 
-		       G_CALLBACK(on_submenu_entry_clicked), dialog); 
-
-      g_signal_connect(button, "clicked", 
-		       menu_entries->activate_cb, appdata); 
+    /* try to center both texts */
+    hildon_button_set_title_alignment(HILDON_BUTTON(button), 0.5, 0.5);
+    hildon_button_set_value_alignment(HILDON_BUTTON(button), 0.5, 0.5);
 
+    g_signal_connect(button, "clicked", 
+		     G_CALLBACK(on_submenu_entry_clicked), dialog); 
+    
+    g_signal_connect(button, "clicked", 
+		     menu_entries->activate_cb, appdata); 
+    
     gtk_table_attach_defaults(GTK_TABLE(table),  button, x, x+1, y, y+1);
     
     x++;
@@ -1626,6 +1637,10 @@ void on_export_clicked(GtkButton *button, appdata_t *appdata) {
 }
 
 static const menu_entry_t submenu_tools_entries[] = {
+#ifdef ENABLE_OSM_GPS_MAP
+  { "Map",              "Display an interactive world map", 
+    G_CALLBACK(cb_menu_map) },
+#endif
   { "Geomath",          "Geocoordinate calculation", 
     G_CALLBACK(cb_menu_geomath) },
   { "Geotext",          "Text analysis",             
@@ -1809,6 +1824,13 @@ void menu_create(appdata_t *appdata) {
   submenu = gtk_menu_new();
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), submenu);
 
+#ifdef ENABLE_OSM_GPS_MAP
+  item = gtk_menu_item_new_with_label( _("Map") );
+  gtk_menu_append(GTK_MENU_SHELL(submenu), item);
+  g_signal_connect(item, "activate", 
+		   GTK_SIGNAL_FUNC(cb_menu_map), appdata);
+#endif
+
   item = gtk_menu_item_new_with_label( _("Geomath") );
   gtk_menu_append(GTK_MENU_SHELL(submenu), item);
   g_signal_connect(item, "activate", 
